Science calculations
====================

Calculus
--------
.. automodule:: aeolus.calc.calculus
   :members:

Diagnostics
-----------
.. automodule:: aeolus.calc.diag
   :members:

Horizontal fluxes
-----------------
.. automodule:: aeolus.calc.flux_h
   :members:

Statistics
----------
.. automodule:: aeolus.calc.stats
   :members:

Tidally-locked coordinates
--------------------------
.. automodule:: aeolus.calc.tl
   :members:
